# vital-python

The official Python Library for [Vital API](https://docs.tryvital.io)

# Install

```
pip install vital
```

# Installing locally

```
poetry build --format sdist
tar -xvf dist/*-`poetry version -s`.tar.gz -O '*/setup.py' > setup.py
```

## Documentation

Please refer to the official [Vital docs](https://docs.tryvital.io) provide a full reference on using this library.
